package app.ara.activities;

import android.content.Intent;
import android.media.MediaPlayer;
import android.os.Handler;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.FrameLayout;
import android.widget.Button;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.SeekBar;
import android.widget.TextView;

import java.util.Timer;

import app.ara.ui.MediaView;
import app.ara.utils.AndroidResources;
import app.ara.utils.app.brest.game.Resource;

public class MediaAcitvity extends AppCompatActivity implements MediaPlayer.OnSeekCompleteListener,
                                                                MediaView.OnStartListener,
                                                                SeekBar.OnSeekBarChangeListener {
    private Resource mResource;
    private Button mInfo;
    private TextView mTitle;

    private FrameLayout mFrameLayout;
    private ImageButton  mButton;
    private MediaView mMediaView;
    private ImageView mImageView;
    private SeekBar mBar;
    private Handler mHandler = new Handler();
    private AutoSeek mAutoSeek;
    private int mCurrentTime;
    private int mEndTime;
    private boolean mUserSeeks=false;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_media);

        mFrameLayout = (FrameLayout) findViewById(R.id.media_viewer);
        mButton = (ImageButton) findViewById(R.id.play);
        mInfo = (Button) findViewById(R.id.info);
        mBar = (SeekBar) findViewById(R.id.seekBar);
        mBar.setOnSeekBarChangeListener(this);

        mTitle = (TextView) findViewById(R.id.title);
        mAutoSeek = new AutoSeek(mHandler);

        mMediaView = new MediaView(this);
        mMediaView.setOnStartListener(this);
        mImageView = new ImageView(this);
        mImageView.setImageResource(R.drawable.audio);

        mFrameLayout.addView(mMediaView);
        mFrameLayout.addView(mImageView);


        if(getIntent().hasExtra("resource"))
        {
            mResource = (Resource) getIntent().getSerializableExtra("resource");
            if(mResource==null) return;

            mTitle.setText(mResource.getTitle());

            String path=mResource.getName();
            if(mResource.isAudio())
            {
                path+="_audio";
                mImageView.setVisibility(View.VISIBLE);
            }
            else
            {
                path+="_video";
                mImageView.setVisibility(View.GONE);
            }

            mMediaView.play(path);
        }

    }

    public void onFullscreen(View v)
    {
        if(mTitle.getVisibility()==View.VISIBLE)
        {
            mTitle.setVisibility(View.GONE);
            mInfo.setVisibility(View.GONE);
        }else
        {
            mTitle.setVisibility(View.VISIBLE);
            mInfo.setVisibility(View.VISIBLE);
        }
    }

    public void onPlayPause(View v)
    {
        if(mMediaView.isPlaying())
        {
            mAutoSeek.stop();
            mButton.setImageResource(android.R.drawable.ic_media_play);
            mMediaView.pause();
        }else
        {
            mAutoSeek.start();
            mButton.setImageResource(android.R.drawable.ic_media_pause);
            mMediaView.start();
        }
    }

    public void onInfos(View v)
    {
        Intent intent = AndroidResources.getViewerIntent(this, mResource);
        intent.putExtra("information", true);
        startActivity(intent);
    }

    @Override
    public void onSeekComplete(MediaPlayer mediaPlayer) {
        mAutoSeek.start();
        mButton.setImageResource(android.R.drawable.ic_media_pause);
    }



    public void onUpdateSeek()
    {
        if(mMediaView.isPlaying())
        {
            mCurrentTime=mMediaView.getTime()/1000;
            mBar.setProgress(mCurrentTime);
        }
    }

    @Override
    public void onProgressChanged(SeekBar seekBar, int i, boolean b) {
        mUserSeeks=b;
    }

    @Override
    public void onStartTrackingTouch(SeekBar seekBar) {

    }

    @Override
    public void onStopTrackingTouch(SeekBar seekBar) {
        if(mUserSeeks)
        {
            mCurrentTime=seekBar.getProgress();
            mMediaView.seek(mCurrentTime*1000);
            mAutoSeek.stop();
            mUserSeeks=false;
        }
    }

    @Override
    public void onStart(MediaView mv) {
        mCurrentTime=mv.getTime()/1000;
        mEndTime=mv.getDuration()/1000;

        mBar.setMax(mEndTime);
        mBar.setProgress(mCurrentTime);
        mMediaView.setOnSeekCompleteListener(this);

        mAutoSeek.start();
        mButton.setImageResource(android.R.drawable.ic_media_pause);
    }

    private class AutoSeek implements Runnable
    {
        private Handler mHandler;
        AutoSeek(Handler h)
        {
            mHandler=h;
        }

        @Override
        public void run() {
            onUpdateSeek();
            mHandler.postDelayed(this, 500);
        }

        public void start()
        {
            mHandler.postDelayed(this, 500);
        }


        public void stop()
        {
            mHandler.removeCallbacks(this);
        }
    }

    protected  void onPause()
    {
        mAutoSeek.stop();
        mMediaView.stop();
        super.onPause();
    }

    protected  void onResume()
    {
        if(mMediaView!=null)
            mMediaView.start();
        super.onResume();
    }

    public void finish()
    {
        mAutoSeek.stop();
        mMediaView.stop();
        super.finish();
    }

}
